@@ -52,7 +52,7 @@ namespace BOOM {
                                        bool minimal = true) override;
     Vector::const_iterator unvectorize(const Vector &v,
                                        bool minimal = true) override;
-    ostream &print(ostream &out) const override;
+    std::ostream &print(std::ostream &out) const override;
 
    private:
     Vector counts_;
@@ -71,7 +71,7 @@ namespace BOOM {
 
     // The argument is a vector of names to use for factor levels to
     // be modeled.
-    explicit MultinomialModel(const std::vector<string> &);
+    explicit MultinomialModel(const std::vector<std::string> &);
 
     explicit MultinomialModel(const MultinomialSuf &suf);
 
