@@ -38,7 +38,7 @@
  *
  *  SYNOPSIS
  *
- *      #include <Bmath.hpp>
+ *      #include "Bmath.hpp"
  *      void rmultinom(int n, double* prob, int K, int* rN);
  *
  *  DESCRIPTION
@@ -54,8 +54,8 @@
  *      => Hence also can have  int arguments.
  */
 
-#include <Bmath/Bmath.hpp>
-#include <cpputil/report_error.hpp>
+#include "Bmath/Bmath.hpp"
+#include "cpputil/report_error.hpp"
 
 #include <vector>
 #include <stdexcept>
@@ -133,6 +133,5 @@ namespace Rmath{
       p_tot -= prob[k]; /* i.e. = sum(prob[(k+1):K]) */
     }
     rN[K-1] = n;
-    return;
   }
-}
+}  // namespace Rmath
