@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2013 Steven L. Scott
 
@@ -16,7 +17,7 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
-#include <Models/Glm/PosteriorSamplers/poisson_mixture_approximation_table.hpp>
+#include "Models/Glm/PosteriorSamplers/poisson_mixture_approximation_table.hpp"
 
 namespace BOOM {
   void fill_poisson_mixture_approximation_table_1(
@@ -34,35 +35,29 @@ namespace BOOM {
   }
 
   BOOM::NormalMixtureApproximationTable
-    create_poisson_mixture_approximation_table() {
+  create_poisson_mixture_approximation_table() {
     BOOM::NormalMixtureApproximationTable table;
     fill_poisson_mixture_approximation_table(&table);
     return table;
   }
 
   void unmix_poisson_augmented_data(
-      RNG &rng,
-      double negative_log_interevent_time_residual,
-      int number_of_events,
-      double *mu,
-      double *sigsq,
+      RNG &rng, double negative_log_interevent_time_residual,
+      int number_of_events, double *mu, double *sigsq,
       NormalMixtureApproximationTable *table) {
     if (number_of_events >= table->largest_index()) {
       // If n is very large then the distribution very close to
       // Gaussian.  The mode can be obtained analytically, and the
       // curvature at the mode is just 1.0/n.
       *mu = -log(number_of_events);
-      *sigsq = 1.0/number_of_events;
+      *sigsq = 1.0 / number_of_events;
       return;
     } else {
       NormalMixtureApproximation approximation(
           table->approximate(number_of_events));
-      approximation.unmix(
-          rng,
-          negative_log_interevent_time_residual,
-          mu,
-          sigsq);
+      approximation.unmix(rng, negative_log_interevent_time_residual, mu,
+                          sigsq);
     }
   }
 
-}
+}  // namespace BOOM
