@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2010 Steven L. Scott
 
@@ -16,43 +17,40 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
-#include <Models/MarginallyUniformCorrelationModel.hpp>
-#include <distributions.hpp>
+#include "Models/MarginallyUniformCorrelationModel.hpp"
+#include "distributions.hpp"
 
-
-namespace BOOM{
+namespace BOOM {
 
   typedef MarginallyUniformCorrelationModel MUCM;
 
-  MUCM::MarginallyUniformCorrelationModel(uint dim)
-      : dim_(dim)
-  {}
+  MUCM::MarginallyUniformCorrelationModel(uint dim) : dim_(dim) {}
 
-  MUCM * MUCM::clone()const{return new MUCM(*this);}
+  MUCM *MUCM::clone() const { return new MUCM(*this); }
 
-  double MUCM::pdf(Ptr<Data> dp, bool logscale)const{
+  double MUCM::pdf(const Ptr<Data> &dp, bool logscale) const {
     // un-normalized!!!
     Ptr<SpdParams> d = DAT(dp);
-    double ans = logp(d->value());
+    double ans = logp(CorrelationMatrix(d->value()));
     return logscale ? ans : exp(ans);
   }
 
-  double MUCM::logp(const CorrelationMatrix & R)const{
+  double MUCM::logp(const CorrelationMatrix &R) const {
     // un-normalized
     uint k = R.dim();
     double ldR = R.logdet();
-    double nu = k+1;
+    double nu = k + 1;
     SpdMatrix Rinv = R.inv();
     double ans = -.5 * (nu + k + 1) * ldR - .5 * sum(log(Rinv.diag()));
     return ans;
   }
 
-  uint MUCM::dim()const{return dim_;}
+  uint MUCM::dim() const { return dim_; }
 
-  CorrelationMatrix MUCM::sim(RNG &rng)const{
+  CorrelationMatrix MUCM::sim(RNG &rng) const {
     uint d = dim();
     SpdMatrix I(d, 1.0);
-    SpdMatrix Sigma = rWish_mt(rng, d+1, I, true); // inverse wishart
+    SpdMatrix Sigma = rWish_mt(rng, d + 1, I, true);  // inverse wishart
     return var2cor(Sigma);
   }
 }  // namespace BOOM
