@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2008 Steven L. Scott
 
@@ -16,14 +17,14 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
-#include <Models/PosteriorSamplers/ZeroMeanGaussianConjSampler.hpp>
-#include <Models/ZeroMeanGaussianModel.hpp>
-#include <Models/GammaModel.hpp>
-#include <Models/ChisqModel.hpp>
-#include <distributions.hpp>
-#include <cpputil/math_utils.hpp>
+#include "Models/PosteriorSamplers/ZeroMeanGaussianConjSampler.hpp"
+#include "Models/ChisqModel.hpp"
+#include "Models/GammaModel.hpp"
+#include "Models/ZeroMeanGaussianModel.hpp"
+#include "cpputil/math_utils.hpp"
+#include "distributions.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
   typedef ZeroMeanGaussianConjSampler ZGS;
 
@@ -33,24 +34,20 @@ namespace BOOM{
       : PosteriorSampler(seeding_rng),
         model_(model),
         precision_prior_(precision_prior),
-        variance_sampler_(precision_prior)
-  {}
+        variance_sampler_(precision_prior) {}
 
-  ZGS::ZeroMeanGaussianConjSampler(ZeroMeanGaussianModel *model,
-                                   double df,
-                                   double sigma_guess,
-                                   RNG &seeding_rng)
+  ZGS::ZeroMeanGaussianConjSampler(ZeroMeanGaussianModel *model, double df,
+                                   double sigma_guess, RNG &seeding_rng)
       : PosteriorSampler(seeding_rng),
         model_(model),
         precision_prior_(new ChisqModel(df, sigma_guess)),
-        variance_sampler_(precision_prior_)
-  {}
+        variance_sampler_(precision_prior_) {}
 
-  ZGS * ZGS::clone()const{ return new ZGS(*this);}
+  ZGS *ZGS::clone() const { return new ZGS(*this); }
 
   void ZGS::draw() {
-    model_->set_sigsq(variance_sampler_.draw(
-        rng(), model_->suf()->n(), model_->suf()->sumsq()));
+    model_->set_sigsq(variance_sampler_.draw(rng(), model_->suf()->n(),
+                                             model_->suf()->sumsq()));
   }
 
   double ZGS::logpri() const {
@@ -72,17 +69,15 @@ namespace BOOM{
   // and not an inverse Gamma model on sigsq.  For this result to agree with
   // numerical optimizers we need to do the optimization with respect to
   // 1/sigsq.
-  void ZGS::find_posterior_mode(double){
+  void ZGS::find_posterior_mode(double) {
     double sigsq_mode = variance_sampler_.posterior_mode(
-        model_->suf()->n(),
-        model_->suf()->sumsq());
+        model_->suf()->n(), model_->suf()->sumsq());
     model_->set_sigsq(sigsq_mode);
   }
 
   double ZGS::increment_log_prior_gradient(const ConstVectorView &parameters,
                                            VectorView gradient) const {
-    if (parameters.size() != 1
-        || gradient.size() != 1) {
+    if (parameters.size() != 1 || gradient.size() != 1) {
       report_error(
           "Wrong size arguments passed to "
           "ZeroMeanGaussianConjSampler::increment_log_prior_gradient.");
@@ -92,8 +87,9 @@ namespace BOOM{
 
   double ZGS::log_prior_density(const ConstVectorView &parameters) const {
     if (parameters.size() != 1) {
-      report_error("Wrong size parameters passed to "
-                   "ZeroMeanGaussianConjSampler::log_prior_density.");
+      report_error(
+          "Wrong size parameters passed to "
+          "ZeroMeanGaussianConjSampler::log_prior_density.");
     }
     return log_prior(parameters[0], nullptr, nullptr);
   }
@@ -114,19 +110,17 @@ namespace BOOM{
         *d2 += (a + 1) / sig4 - 2 * b / sig6;
       }
     }
-    return dgamma(1/sigsq, a, b, true) - 2 * log(sigsq);
+    return dgamma(1 / sigsq, a, b, true) - 2 * log(sigsq);
   }
 
   double ZGS::log_posterior(double sigsq, double &d1, double &d2,
                             uint nd) const {
     // The log likelihood is already parameterized with respect to
     // sigma^2, so derivatives are easy.
-    double logp = model_->log_likelihood(sigsq,
-                                         nd > 0 ? &d1 : nullptr,
+    double logp = model_->log_likelihood(sigsq, nd > 0 ? &d1 : nullptr,
                                          nd > 1 ? &d2 : nullptr);
-    return logp + log_prior(sigsq,
-                            nd > 0 ? &d1 : nullptr,
-                            nd > 1 ? &d2 : nullptr);
+    return logp +
+           log_prior(sigsq, nd > 0 ? &d1 : nullptr, nd > 1 ? &d2 : nullptr);
   }
 
 }  // namespace BOOM
