@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2008-2011 Steven L. Scott
 
@@ -16,66 +17,61 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
-#include <Models/ZeroMeanGaussianModel.hpp>
-#include <Models/GammaModel.hpp>
-#include <cpputil/math_utils.hpp>
+#include "Models/ZeroMeanGaussianModel.hpp"
+#include "Models/GammaModel.hpp"
+#include "cpputil/math_utils.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
   typedef ZeroMeanGaussianModel ZGM;
 
   ZGM::ZeroMeanGaussianModel(double sigma)
-      : ParamPolicy(new UnivParams(sigma * sigma))
-  {}
+      : ParamPolicy(new UnivParams(sigma * sigma)) {}
 
   ZGM::ZeroMeanGaussianModel(const std::vector<double> &y)
-      : GaussianModelBase(y),
-        ParamPolicy(new UnivParams(1.0))
-  {
+      : GaussianModelBase(y), ParamPolicy(new UnivParams(1.0)) {
     mle();
   }
 
-  ZGM * ZGM::clone()const{return new ZGM(*this);}
+  ZGM *ZGM::clone() const { return new ZGM(*this); }
 
-  void ZGM::set_sigsq(double s2){
-    Sigsq_prm()->set(s2);}
+  void ZGM::set_sigsq(double s2) { Sigsq_prm()->set(s2); }
 
-  Ptr<UnivParams> ZGM::Sigsq_prm(){
-    return ParamPolicy::prm();}
+  Ptr<UnivParams> ZGM::Sigsq_prm() { return ParamPolicy::prm(); }
 
-  const Ptr<UnivParams> ZGM::Sigsq_prm()const{
-    return ParamPolicy::prm();}
+  const Ptr<UnivParams> ZGM::Sigsq_prm() const { return ParamPolicy::prm(); }
 
-  double ZGM::sigsq()const{return Sigsq_prm()->value();}
-  double ZGM::sigma()const{return sqrt(sigsq());}
+  double ZGM::sigsq() const { return Sigsq_prm()->value(); }
+  double ZGM::sigma() const { return sqrt(sigsq()); }
 
-  void ZGM::mle(){
+  void ZGM::mle() {
     double n = suf()->n();
     double ss = suf()->sumsq();
-    if(n>0) set_sigsq(ss/n);
-    else set_sigsq(1.0);
+    if (n > 0)
+      set_sigsq(ss / n);
+    else
+      set_sigsq(1.0);
   }
 
   double ZGM::log_likelihood(double sigsq, double *d1, double *d2) const {
-    if(sigsq<0) return BOOM::negative_infinity();
+    if (sigsq < 0) return BOOM::negative_infinity();
     const double log2pi = 1.8378770664093453;
     double n = suf()->n();
     double sumsq = suf()->sumsq();
     double ans = -0.5 * (n * (log2pi + log(sigsq)) + sumsq / sigsq);
-    if(d1){
+    if (d1) {
       double sig4 = sigsq * sigsq;
-      *d1 = .5 * ( (sumsq / sig4) - (n / sigsq));
-      if(d2) {
-        *d2 = (n/2 - sumsq / sigsq) / sig4;
+      *d1 = .5 * ((sumsq / sig4) - (n / sigsq));
+      if (d2) {
+        *d2 = (n / 2 - sumsq / sigsq) / sig4;
       }
     }
     return ans;
   }
 
-  double ZGM::Loglike(const Vector &sigsq_vec,
-                      Vector &g, Matrix &h, uint nd)const{
-    return log_likelihood(sigsq_vec[0],
-                          nd > 0 ? &g[0] : nullptr,
+  double ZGM::Loglike(const Vector &sigsq_vec, Vector &g, Matrix &h,
+                      uint nd) const {
+    return log_likelihood(sigsq_vec[0], nd > 0 ? &g[0] : nullptr,
                           nd > 1 ? &h(0, 0) : nullptr);
   }
-} // namespace BOOM
+}  // namespace BOOM
