@@ -30,15 +30,18 @@ namespace BOOM {
   double rtg_init(double x, double a, double b, double cut, double logpstar);
   double rtg_slice(RNG &, double x, double a, double b, double cut);
 
-  double dtrun_gamma(double x, double a, double b, double cut, bool logscale) {
-    /*
-     * return the un-normalized density of a gamma(a,b) random
-     * variable x, given x > cut
-     */
+  double dtrun_gamma(double x, double a, double b, double cut,
+                     bool logscale, bool normalize) {
+    if (a < 0 || b < 0 || cut < 0 || x < cut) {
+      return BOOM::negative_infinity();
+    }
 
-    if (a < 0 || b < 0 || cut < 0 || x < cut) return BOOM::negative_infinity();
-
-    double ans = (a - 1) * log(x) - b * x;
+    double ans;
+    if (normalize) {
+      ans = dgamma(x, a, b, true) - pgamma(cut, a, b, false, true);
+    } else {
+      ans = (a - 1) * log(x) - b * x;
+    }
     return logscale ? ans : exp(ans);
   }
 
@@ -47,7 +50,7 @@ namespace BOOM {
    public:
     LogGammaDensity(double a, double b, double cut) : a_(a), b_(b), cut_(cut) {}
     double operator()(double x) const {
-      return dtrun_gamma(x, a_, b_, cut_, true);
+      return dtrun_gamma(x, a_, b_, cut_, true, false);
     }
 
    private:
@@ -67,7 +70,7 @@ namespace BOOM {
     return rtrun_gamma_mt(GlobalRng::rng, a, b, cut, n);
   }
 
-  double rtrun_gamma_mt(RNG &rng, double a, double b, double cut, unsigned n) {
+  double rtrun_gamma_mt(RNG &rng, double a, double b, double cut, unsigned nslice) {
     double mode = (a - 1) / b;
     double x = cut;
     if (cut < mode) {  // rejection sampling
@@ -89,13 +92,15 @@ namespace BOOM {
             << "  a = " << a << std::endl
             << "  b = " << b << std::endl
             << "cut = " << cut << std::endl
-            << "  n = " << n << std::endl;
+            << "  nslice = " << nslice << std::endl;
         report_error(err.str());
       } catch (...) {
         report_error("caught unknown exception in rtrun_gamma_mt");
       }
     } else {
-      for (unsigned i = 0; i < n; ++i) x = rtg_slice(rng, x, a, b, cut);
+      for (unsigned i = 0; i < nslice; ++i) {
+        x = rtg_slice(rng, x, a, b, cut);
+      }
     }
     return x;
   }
@@ -111,10 +116,15 @@ namespace BOOM {
 
     double f = dtrun_gamma(x, a, b, cut, true) - logpstar;
     double fprime = ((a - 1) / x) - b;
-    while (f > 0) {
+    int attempts = 0;
+    int max_attempts = 1000;
+    while (f > sqrt(std::numeric_limits<double>::epsilon())) {
       x -= f / fprime;
       f = dtrun_gamma(x, a, b, cut, true) - logpstar;
       fprime = ((a - 1) / cut) - b;
+      if (++attempts > max_attempts) {
+        break;
+      }
     }
     return x;
   }
@@ -124,9 +134,14 @@ namespace BOOM {
     double lo = cut;
     double hi = rtg_init(x, a, b, cut, logpstar);
     x = runif_mt(rng, lo, hi);
+    int trials = 0;
+    int max_trials = 1000;
     while (dtrun_gamma(x, a, b, cut, true) < logpstar) {
       hi = x;
       x = runif_mt(rng, lo, hi);
+      if (++trials > max_trials) {
+        return cut;
+      }
     }
     return (x);
   }
