@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005 Steven L. Scott
 
@@ -17,31 +18,28 @@
 */
 
 #include <cmath>
-#include <LinAlg/Vector.hpp>
+#include "LinAlg/Vector.hpp"
 
+#include "cpputil/math_utils.hpp"
 
-#include <cpputil/math_utils.hpp>
-
-#include <distributions.hpp>
-#include <numopt.hpp>
+#include "distributions.hpp"
+#include "numopt.hpp"
 
 // Shamelessly adapted from R by Steven Scott.  The original comment
 // below mentions an argument 'trace', which I removed.
 
-namespace BOOM{
-  const double E1 =  1.7182818;  /* exp(1.0)-1.0 */
-  const double big =  1.0e+35;    /*a very large number*/
-
-  double simulated_annealing(Vector & pb, Target target, int maxit,
-                             int tmax, double ti){
+namespace BOOM {
+  const double E1 = 1.7182818; /* exp(1.0)-1.0 */
+  const double big = 1.0e+35;  /*a very large number*/
 
+  double simulated_annealing(Vector &pb, const Target &target, int maxit,
+                             int tmax, double ti) {
     /* Given a starting point pb[0..n-1], simulated annealing
        minimization is performed on the function fminfn. The starting
        temperature is input as ti. To make sann work silently set
        trace to zero.  sann makes in total maxit function evaluations,
        tmax evaluations at each temperature. Returned quantities are
        pb (the location of the minimum), and yb (the minimum value of
-       the function func).  Author: Adrian Trapletti
     */
     long i, j;
     int k, its, itdoc;
@@ -53,35 +51,38 @@ namespace BOOM{
     Vector dp(n);
     Vector ptry(n);
     double yb = target(pb);
-    if(!std::isfinite(yb)) yb = big;
+    if (!std::isfinite(yb)) yb = big;
 
     for (j = 0; j < n; j++) p[j] = pb[j];
-    y = yb;  /* init system state p, y */
-    scale = 1.0/ti;
+    y = yb; /* init system state p, y */
+    scale = 1.0 / ti;
     its = itdoc = 1;
-    while (its < maxit) { /* cool down system */
-      t = ti/log((double)its + E1);  /* temperature annealing schedule */
+    while (its < maxit) {             /* cool down system */
+      t = ti / log((double)its + E1); /* temperature annealing schedule */
       k = 1;
-      while ((k <= tmax) && (its < maxit))  /* iterate at constant temperature */
-        {
-          for (i = 0; i < n; i++)
-            dp[i] = scale * t * rnorm(0,1);  /* random perturbation */
-          for (i = 0; i < n; i++)
-            ptry[i] = p[i] + dp[i];  /* new candidate point */
-          ytry = target(ptry);         //fminfn (n, ptry, ex);
-          if(!std::isfinite(ytry)) ytry = big;
-          dy = ytry - y;
-          if ((dy <= 0.0) || (runif(0,1) < exp(-dy/t))) {  /* accept new point? */
-            for (j = 0; j < n; j++) p[j] = ptry[j];
-            y = ytry;  /* update system state p, y */
-            if (y <= yb)  /* if system state is best, then update best system state pb, yb */
-              {
-                for (j = 0; j < n; j++) pb[j] = p[j];
-                yb = y;
-              }
+      while ((k <= tmax) && (its < maxit)) /* iterate at constant temperature */
+      {
+        for (i = 0; i < n; i++)
+          dp[i] = scale * t * rnorm(0, 1); /* random perturbation */
+        for (i = 0; i < n; i++)
+          ptry[i] = p[i] + dp[i]; /* new candidate point */
+        ytry = target(ptry);      // fminfn (n, ptry, ex);
+        if (!std::isfinite(ytry)) ytry = big;
+        dy = ytry - y;
+        if ((dy <= 0.0) ||
+            (runif(0, 1) < exp(-dy / t))) { /* accept new point? */
+          for (j = 0; j < n; j++) p[j] = ptry[j];
+          y = ytry;    /* update system state p, y */
+          if (y <= yb) /* if system state is best, then update best system state
+                          pb, yb */
+          {
+            for (j = 0; j < n; j++) pb[j] = p[j];
+            yb = y;
           }
-          its++; k++;
         }
+        its++;
+        k++;
+      }
       itdoc++;
     }
     return yb;
